package com.gem.media.ad;

public interface AdStatusCallBack {


    void onAdLoad(String type, String ad_type, String reason, long time, String adId, String scenario);
    void onAdLoaded(String type, String ad_type, String reason, long time, String adId, String scenario);
    void onNoAdError(String type, String ad_type, String reason, long time, String adId, String scenario);
    void onAdShow(String type, String ad_type, String reason, long time, String adId, String scenario);
    void onAdClick(String type, String ad_type, String reason, long time, String adId, String scenario);
    void onAdDismiss(String type, String ad_type, String reason, long time, String adId, String scenario);
    void nextMediaAppAdReq(String type, String ad_type, String reason, long time, String adId, String scenario);
}
